pub struct LoggerConfig {Show 13 fields
pub stdout_level: LevelFilter,
pub fileout_level: LevelFilter,
pub component_level: AHashMap<Ustr, LevelFilter>,
pub module_level: AHashMap<Ustr, LevelFilter>,
pub log_components_only: bool,
pub is_colored: bool,
pub print_config: bool,
pub use_tracing: bool,
pub bypass_logging: bool,
pub file_config: Option<FileWriterConfig>,
pub clear_log_file: bool,
pub fileout_sync_on_flush: bool,
pub buffered_stdout: bool,
}Expand description
Configuration for the Nautilus logger.
Fields
stdout_level: LevelFilterMaximum log level for stdout output.
fileout_level: LevelFilterMaximum log level for file output (Off disables file logging).
component_level: AHashMap<Ustr, LevelFilter>Per-component log level overrides (exact match).
module_level: AHashMap<Ustr, LevelFilter>Per-module path log level overrides (prefix match).
log_components_only: boolLog only components with explicit level filters.
is_colored: boolUse ANSI color codes in output.
print_config: boolPrint configuration to stdout at startup.
use_tracing: boolInitialize the tracing subscriber for external Rust crate logs.
bypass_logging: boolIf all logging should be bypassed.
file_config: Option<FileWriterConfig>File writer configuration for log file output.
clear_log_file: boolIf the log file should be cleared before use.
fileout_sync_on_flush: boolIf file log flushes should also sync data to disk.
buffered_stdout: boolIf stdout writes should be buffered until flush or buffer capacity.
Implementations
Sourceimpl LoggerConfig
impl LoggerConfig
Sourcepub fn builder() -> LoggerConfigBuilder
pub fn builder() -> LoggerConfigBuilder
Create an instance of LoggerConfig using the builder syntax
Sourceimpl LoggerConfig
impl LoggerConfig
Sourcepub fn new(
stdout_level: LevelFilter,
fileout_level: LevelFilter,
component_level: AHashMap<Ustr, LevelFilter>,
module_level: AHashMap<Ustr, LevelFilter>,
log_components_only: bool,
is_colored: bool,
print_config: bool,
use_tracing: bool,
bypass_logging: bool,
file_config: Option<FileWriterConfig>,
clear_log_file: bool,
) -> Self
pub fn new( stdout_level: LevelFilter, fileout_level: LevelFilter, component_level: AHashMap<Ustr, LevelFilter>, module_level: AHashMap<Ustr, LevelFilter>, log_components_only: bool, is_colored: bool, print_config: bool, use_tracing: bool, bypass_logging: bool, file_config: Option<FileWriterConfig>, clear_log_file: bool, ) -> Self
Creates a new LoggerConfig instance.
Sourcepub fn validate(&self) -> ConfigResult<()>
pub fn validate(&self) -> ConfigResult<()>
Validates the logger configuration.
Errors
Returns a ConfigError if the file writer configuration
is invalid (see FileWriterConfig::validate).
Sourceimpl LoggerConfig
impl LoggerConfig
Sourcepub fn py_from_spec(spec: &str) -> PyResult<Self>
pub fn py_from_spec(spec: &str) -> PyResult<Self>