LoggerConfig

Struct LoggerConfig 

pub struct LoggerConfig {
    pub stdout_level: LevelFilter,
    pub fileout_level: LevelFilter,
    pub component_level: AHashMap<Ustr, LevelFilter>,
    pub module_level: AHashMap<Ustr, LevelFilter>,
    pub log_components_only: bool,
    pub is_colored: bool,
    pub print_config: bool,
    pub use_tracing: bool,
    pub bypass_logging: bool,
    pub file_config: Option<FileWriterConfig>,
    pub clear_log_file: bool,
}
Configuration for the Nautilus logger.

Fields

stdout_level: LevelFilter

Maximum log level for stdout output.

fileout_level: LevelFilter

Maximum log level for file output (Off disables file logging).

component_level: AHashMap<Ustr, LevelFilter>

Per-component log level overrides (exact match).

module_level: AHashMap<Ustr, LevelFilter>

Per-module path log level overrides (prefix match).

log_components_only: bool

Log only components with explicit level filters.

is_colored: bool

Use ANSI color codes in output.

print_config: bool

Print configuration to stdout at startup.

use_tracing: bool

Initialize the tracing subscriber for external Rust crate logs.

bypass_logging: bool

If all logging should be bypassed.

file_config: Option<FileWriterConfig>

File writer configuration for log file output.

clear_log_file: bool

If the log file should be cleared before use.

Implementations

Source

impl LoggerConfig

pub fn builder() -> LoggerConfigBuilder

Create an instance of LoggerConfig using the builder syntax

Source

impl LoggerConfig

pub fn new( stdout_level: LevelFilter, fileout_level: LevelFilter, component_level: AHashMap<Ustr, LevelFilter>, module_level: AHashMap<Ustr, LevelFilter>, log_components_only: bool, is_colored: bool, print_config: bool, use_tracing: bool, bypass_logging: bool, file_config: Option<FileWriterConfig>, clear_log_file: bool, ) -> Self

Creates a new LoggerConfig instance.

pub fn from_spec(spec: &str) -> Result<Self>

Parses a configuration from a spec string.

Format

Semicolon-separated key-value pairs or bare flags:

stdout=Info;fileout=Debug;RiskEngine=Error;my_crate::module=Debug;is_colored
Errors

Returns an error if the spec string contains invalid syntax or log levels.

pub fn from_env() -> Result<Self>

Parses configuration from the NAUTILUS_LOG environment variable.

Errors

Returns an error if the variable is unset or contains invalid syntax.

Source

impl LoggerConfig

pub fn py_from_spec(spec: &str) -> PyResult<Self>

Parses a configuration from a spec string.

Format

Semicolon-separated key-value pairs or bare flags:

stdout=Info;fileout=Debug;RiskEngine=Error;my_crate::module=Debug;is_colored
Errors

Returns an error if the spec string contains invalid syntax or log levels.